---
name: Feature request
about: Development issue describing something new to be added to the project
title: "<subject title related to the issue>"
labels: "type: feature request"
assignees: ""
---

## Context

<!--- Provide some context why is this feature needed.
Does it build from an existing feature, does it enable an implementation of some other new feature? -->

## Required steps / Implementation details

<!--- Either provide a list of steps that are required for this feature and/or provide technical details on how this feature will be implemented. -->

## Definition of Done

<!--- Explicitly define conditions when this feature request is considered done, so it can be reviewed and validated. -->

<!-- For example: Described feature is implemented, documented, tested and reviewed. -->
